@@ -72,6 +72,56 @@ class CreateAsrVocabResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CreateCustomizationRequest(AbstractModel):
+    """CreateCustomization请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ModelName: 自学习模型名称，需在1-20字符之间
+        :type ModelName: str
+        :param TextUrl: 文本文件的下载地址，服务会从该地址下载文件， 以训练模型，目前仅支持腾讯云cos
+        :type TextUrl: str
+        :param ModelType: 自学习模型类型，填写8k或者16k
+        :type ModelType: str
+        :param TagInfos: 标签信息
+        :type TagInfos: list of str
+        """
+        self.ModelName = None
+        self.TextUrl = None
+        self.ModelType = None
+        self.TagInfos = None
+
+
+    def _deserialize(self, params):
+        self.ModelName = params.get("ModelName")
+        self.TextUrl = params.get("TextUrl")
+        self.ModelType = params.get("ModelType")
+        self.TagInfos = params.get("TagInfos")
+
+
+class CreateCustomizationResponse(AbstractModel):
+    """CreateCustomization返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ModelId: 模型ID
+        :type ModelId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ModelId = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.ModelId = params.get("ModelId")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateRecTaskRequest(AbstractModel):
     """CreateRecTask请求参数结构体
 
@@ -81,6 +131,7 @@ class CreateRecTaskRequest(AbstractModel):
         """
         :param EngineModelType: 引擎模型类型。
 电话场景：
+• 8k_en：电话 8k 英语；
 • 8k_zh：电话 8k 中文普通话通用（可用于双声道音频）；
 • 8k_zh_s：电话 8k 中文普通话话者分离（仅适用于单声道音频）；
 非电话场景：
@@ -93,7 +144,7 @@ class CreateRecTaskRequest(AbstractModel):
         :type EngineModelType: str
         :param ChannelNum: 语音声道数。1：单声道；2：双声道（仅支持 8k_zh 引擎模型）。
         :type ChannelNum: int
-        :param ResTextFormat: 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：仅支持16k中文引擎，含词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(词时间戳列表，一般用于生成字幕场景)。
+        :param ResTextFormat: 识别结果返回形式。0： 识别结果文本(含分段时间戳)； 1：词级别粒度的[详细识别结果](https://cloud.tencent.com/document/api/1093/37824#SentenceDetail)(不含标点，词时间戳列表，一般用于生成字幕场景)；2：词级别粒度的详细识别结果（包含标点）
         :type ResTextFormat: int
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
         :type SourceType: int
@@ -217,6 +268,40 @@ class DeleteAsrVocabResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DeleteCustomizationRequest(AbstractModel):
+    """DeleteCustomization请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ModelId: 要删除的模型ID
+        :type ModelId: str
+        """
+        self.ModelId = None
+
+
+    def _deserialize(self, params):
+        self.ModelId = params.get("ModelId")
+
+
+class DeleteCustomizationResponse(AbstractModel):
+    """DeleteCustomization返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeTaskStatusRequest(AbstractModel):
     """DescribeTaskStatus请求参数结构体
 
@@ -299,6 +384,44 @@ class DownloadAsrVocabResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DownloadCustomizationRequest(AbstractModel):
+    """DownloadCustomization请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ModelId: 自学习模型ID
+        :type ModelId: str
+        """
+        self.ModelId = None
+
+
+    def _deserialize(self, params):
+        self.ModelId = params.get("ModelId")
+
+
+class DownloadCustomizationResponse(AbstractModel):
+    """DownloadCustomization返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param DownloadUrl: 下载地址
+        :type DownloadUrl: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.DownloadUrl = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.DownloadUrl = params.get("DownloadUrl")
+        self.RequestId = params.get("RequestId")
+
+
 class GetAsrVocabListRequest(AbstractModel):
     """GetAsrVocabList请求参数结构体
 
@@ -545,6 +668,94 @@ class Model(AbstractModel):
         self.TagInfos = params.get("TagInfos")
 
 
+class ModifyCustomizationRequest(AbstractModel):
+    """ModifyCustomization请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ModelId: 要修改的模型ID
+        :type ModelId: str
+        :param ModelName: 要修改的模型名称，长度需在1-20个字符之间
+        :type ModelName: str
+        :param ModelType: 要修改的模型类型，为8k或者16k
+        :type ModelType: str
+        :param TextUrl: 要修改的模型语料的下载地址，目前仅支持腾讯云cos
+        :type TextUrl: str
+        """
+        self.ModelId = None
+        self.ModelName = None
+        self.ModelType = None
+        self.TextUrl = None
+
+
+    def _deserialize(self, params):
+        self.ModelId = params.get("ModelId")
+        self.ModelName = params.get("ModelName")
+        self.ModelType = params.get("ModelType")
+        self.TextUrl = params.get("TextUrl")
+
+
+class ModifyCustomizationResponse(AbstractModel):
+    """ModifyCustomization返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class ModifyCustomizationStateRequest(AbstractModel):
+    """ModifyCustomizationState请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ModelId: 自学习模型ID
+        :type ModelId: str
+        :param ToState: 想要变换的模型状态，-1代表下线，1代表上线
+        :type ToState: int
+        """
+        self.ModelId = None
+        self.ToState = None
+
+
+    def _deserialize(self, params):
+        self.ModelId = params.get("ModelId")
+        self.ToState = params.get("ToState")
+
+
+class ModifyCustomizationStateResponse(AbstractModel):
+    """ModifyCustomizationState返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ModelId: 自学习模型ID
+        :type ModelId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ModelId = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.ModelId = params.get("ModelId")
+        self.RequestId = params.get("RequestId")
+
+
 class SentenceDetail(AbstractModel):
     """单句的详细识别结果，包含单个词的时间偏移，一般用于生成字幕的场景。
 
@@ -570,6 +781,9 @@ class SentenceDetail(AbstractModel):
         :param Words: 单句中词详情
 注意：此字段可能返回 null，表示取不到有效值。
         :type Words: list of SentenceWords
+        :param SpeechSpeed: 单句语速
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SpeechSpeed: float
         """
         self.FinalSentence = None
         self.SliceSentence = None
@@ -577,6 +791,7 @@ class SentenceDetail(AbstractModel):
         self.EndMs = None
         self.WordsNum = None
         self.Words = None
+        self.SpeechSpeed = None
 
 
     def _deserialize(self, params):
@@ -591,6 +806,7 @@ class SentenceDetail(AbstractModel):
                 obj = SentenceWords()
                 obj._deserialize(item)
                 self.Words.append(obj)
+        self.SpeechSpeed = params.get("SpeechSpeed")
 
 
 class SentenceRecognitionRequest(AbstractModel):
@@ -613,9 +829,6 @@ class SentenceRecognitionRequest(AbstractModel):
 • 16k_en：16k 英语；
 • 16k_ca：16k 粤语；
 • 16k_ja：16k 日语；
-•16k_wuu-SH：16k 上海话方言。
-• 16k_ca：16k 粤语；
-• 16k_ja：16k 日语；
 •16k_wuu-SH：16k 上海话方言。
         :type EngSerViceType: str
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
